<link href="{{url_for('uls.uls_static', fn='jquery.uls/css/jquery.uls.css')}}" rel="stylesheet">
<link href="{{url_for('uls.uls_static', fn='jquery.uls/css/jquery.uls.grid.css')}}" rel="stylesheet">
<link href="{{url_for('uls.uls_static', fn='jquery.uls/css/jquery.uls.lcd.css')}}" rel="stylesheet">
<link href="{{url_for('uls.uls_static', fn='jquery.uls/css/jquery.uls.lcd.css')}}" rel="stylesheet">
<link href="{{url_for('uls.uls_static', fn='flask-uls.css')}}" rel="stylesheet">
